"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RefType = void 0;
/**
 * https://jats.nlm.nih.gov/archiving/tag-library/1.3/attribute/ref-type.html
 */
var RefType;
(function (RefType) {
    /** Affiliation */
    RefType["aff"] = "aff";
    /** Appendix */
    RefType["app"] = "app";
    /** Author notes */
    RefType["author-note"] = "author-note";
    /** Points to the description of or identifier for a grant or award (<award-id>), also, possibly to an entire awards group (<award-group>) */
    RefType["award"] = "award";
    /** Bibliographic reference (typically to a <ref> element, but it may point to a <element-citation> or <mixed-citation> if there are multiple citations inside the <ref> element) */
    RefType["bibr"] = "bibr";
    /** Biography (typically of a contributor) */
    RefType["bio"] = "bio";
    /** Textbox or sidebar */
    RefType["boxed-text"] = "boxed-text";
    /** Chemical structure (to a <chem-struct> or <chem-struct-wrap> element) */
    RefType["chem"] = "chem";
    /** Collaboration */
    RefType["collab"] = "collab";
    /** Contributor */
    RefType["contrib"] = "contrib";
    /** Corresponding author */
    RefType["corresp"] = "corresp";
    /** The value “custom” is used in versions of JATS that have a static list of values for the @ref-type attribute. To add a value to such a list, the cross reference is given the type “custom” and a separate @custom-type attribute provides the typing value. There is no need for this mechanism in Archiving, since there are no restrictions on the value of @ref-type, but “custom” and @custom-type have both been included in Archiving so that documents valid to a stricter version of the JATS Tag Set will also be valid to Archiving. */
    RefType["custom"] = "custom";
    /** Display formula */
    RefType["disp-formula"] = "disp-formula";
    /** Figure or group of figures (to a <fig> or <fig-group> element) */
    RefType["fig"] = "fig";
    /** Footnote */
    RefType["fn"] = "fn";
    /** Keyword */
    RefType["kwd"] = "kwd";
    /** List or list item (to a <list> or <list-item> element; also, possibly to a <def-list> or <def-item> element) */
    RefType["list"] = "list";
    /** Plate */
    RefType["plate"] = "plate";
    /** Scheme */
    RefType["scheme"] = "scheme";
    /** Section */
    RefType["sec"] = "sec";
    /** Statement */
    RefType["statement"] = "statement";
    /** Supplementary information */
    RefType["supplementary-material"] = "supplementary-material";
    /** Table or group of tables (to a <table-wrap> or <table-wrap-group> element) */
    RefType["table"] = "table";
    /** Table footnote */
    RefType["table-fn"] = "table-fn";
})(RefType = exports.RefType || (exports.RefType = {}));
//# sourceMappingURL=types.js.map